<?php

namespace SALESmanago\Controller\User\Vendor;

use SALESmanago\Adapter\ConfigurationStoreAdapterInterface;
use SALESmanago\Entity\Api\V3\Auth\ApiKeyMetaEntity;
use SALESmanago\Entity\Configuration;
use SALESmanago\Entity\Response;
use SALESmanago\Entity\UnionConfigurationEntity;
use SALESmanago\Entity\UnionConfigurationInterface;
use SALESmanago\Entity\User;
use SALESmanago\Exception\ApiV3Exception;
use SALESmanago\Exception\Exception;
use SALESmanago\Model\Report\ReportModel;
use SALESmanago\Services\Api\V3\AuthService;
use SALESmanago\Services\Report\ReportService;
use SALESmanago\Services\UserAccountService;

class AccountController
{
    /**
     * @var UnionConfigurationInterface
     */
    protected $conf;

    /**
     * @var UserAccountService
     */
    protected $service;

    /**
     * @var ConfigurationStoreAdapterInterface
     */
    protected $ConfigurationStoreAdapter;

    /**
     * LoginController constructor.
     *
     * @param UnionConfigurationInterface $conf
     * @param ConfigurationStoreAdapterInterface|null $ConfigurationStoreAdapter
     * @throws Exception
     */
    public function __construct(
        UnionConfigurationInterface $conf,
        ?ConfigurationStoreAdapterInterface $ConfigurationStoreAdapter
    ) {
        UnionConfigurationEntity::setInstance($conf);

        $this->conf                      = $conf;
        $this->ConfigurationStoreAdapter = $ConfigurationStoreAdapter;
        $this->service                   = new UserAccountService($this->conf);
    }

    /**
     * Login into sm account
     *
     * @param User $User
     * @return Response
     * @throws Exception
     * @throws ApiV3Exception
     */
    public function login(User $User)
    {
        $Response = $this->service->login($User);

        (new AuthService($this->conf))
            ->create(
                $User,
                (new ApiKeyMetaEntity())
                    ->setEndpoint(str_replace('https://', '', $this->conf->getEndpoint()))
            );

        try {
            if (!empty($this->ConfigurationStoreAdapter)) {
                $this->ConfigurationStoreAdapter->storeUnionConfiguration($this->conf);
            }

            ReportService::getInstance($this->conf)
                ->reportAction(ReportModel::ACT_LOGIN);
        } catch (\Exception $e) {
            throw new Exception($e->getMessage(), $e->getCode());
        }

        return $Response;
    }

    /**
     * Logout from account
     *
     * @return Response|null
     * @throws ApiV3Exception|Exception
     */
    public function logout()
    {
        $Response = (new AuthService($this->conf))->revoke();

        if (!empty($this->ConfigurationStoreAdapter)) {
            $this->ConfigurationStoreAdapter->removeConfiguration();
            $this->ConfigurationStoreAdapter->removeAuthConfiguration();
        }

        ReportService::getInstance($this->conf)
            ->reportAction(ReportModel::ACT_LOGOUT);

        return $Response;
    }
}